==> hibernate-core-6.0.0.Final-sources.jar: org/hibernate/sql/results/graph/collection/internal/ArrayInitializerProducer.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or http://www.gnu.org/licenses/lgpl-2.1.html
 */
package org.hibernate.sql.results.graph.collection.internal;

import org.hibernate.LockMode;
import org.hibernate.collection.spi.CollectionInitializerProducer;
import org.hibernate.metamodel.mapping.PluralAttributeMapping;
import org.hibernate.spi.NavigablePath;
import org.hibernate.sql.results.graph.AssemblerCreationState;
import org.hibernate.sql.results.graph.DomainResultAssembler;
import org.hibernate.sql.results.graph.Fetch;
import org.hibernate.sql.results.graph.FetchParentAccess;
import org.hibernate.sql.results.graph.collection.CollectionInitializer;

/**
 * @author Chris Cranford
 */
public class ArrayInitializerProducer implements CollectionInitializerProducer {
	private final PluralAttributeMapping arrayDescriptor;
	private final Fetch listIndexFetch;
	private final Fetch elementFetch;

	public ArrayInitializerProducer(
			PluralAttributeMapping arrayDescriptor,
			Fetch listIndexFetch,
			Fetch elementFetch) {
		this.arrayDescriptor = arrayDescriptor;
		this.listIndexFetch = listIndexFetch;
		this.elementFetch = elementFetch;
	}

	@Override
	public CollectionInitializer produceInitializer(
			NavigablePath navigablePath,
			PluralAttributeMapping attributeMapping,
			FetchParentAccess parentAccess,
			LockMode lockMode,
			DomainResultAssembler<?> collectionKeyAssembler,
			DomainResultAssembler<?> collectionValueKeyAssembler,
			AssemblerCreationState creationState) {
		//noinspection unchecked
		return new ArrayInitializer(
				navigablePath,
				arrayDescriptor,
				parentAccess,
				lockMode,
				collectionKeyAssembler,
				collectionValueKeyAssembler,
				(DomainResultAssembler<Integer>) listIndexFetch.createAssembler( parentAccess, creationState ),
				elementFetch.createAssembler( parentAccess, creationState )
		);
	}
}

==> hibernate-core-6.5.2.Final-sources.jar: org/hibernate/sql/results/graph/collection/internal/ArrayInitializerProducer.java <==
/*
 * Hibernate, Relational Persistence for Idiomatic Java
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or http://www.gnu.org/licenses/lgpl-2.1.html
 */
package org.hibernate.sql.results.graph.collection.internal;

import org.hibernate.LockMode;
import org.hibernate.collection.spi.CollectionInitializerProducer;
import org.hibernate.metamodel.mapping.PluralAttributeMapping;
import org.hibernate.spi.NavigablePath;
import org.hibernate.sql.results.graph.AssemblerCreationState;
import org.hibernate.sql.results.graph.DomainResult;
import org.hibernate.sql.results.graph.DomainResultAssembler;
import org.hibernate.sql.results.graph.Fetch;
import org.hibernate.sql.results.graph.FetchParentAccess;
import org.hibernate.sql.results.graph.collection.CollectionInitializer;

/**
 * @author Chris Cranford
 */
public class ArrayInitializerProducer implements CollectionInitializerProducer {
	private final PluralAttributeMapping arrayDescriptor;
	private final Fetch listIndexFetch;
	private final Fetch elementFetch;

	public ArrayInitializerProducer(
			PluralAttributeMapping arrayDescriptor,
			Fetch listIndexFetch,
			Fetch elementFetch) {
		this.arrayDescriptor = arrayDescriptor;
		this.listIndexFetch = listIndexFetch;
		this.elementFetch = elementFetch;
	}

	@Override
	public CollectionInitializer produceInitializer(
			NavigablePath navigablePath,
			PluralAttributeMapping attributeMapping,
			FetchParentAccess parentAccess,
			LockMode lockMode,
			DomainResultAssembler<?> collectionKeyAssembler,
			DomainResultAssembler<?> collectionValueKeyAssembler,
			AssemblerCreationState creationState) {
		throw new UnsupportedOperationException( "Use the non-deprecated method variant instead." );
	}

	@Override
	public CollectionInitializer produceInitializer(
			NavigablePath navigablePath,
			PluralAttributeMapping attribute,
			FetchParentAccess parentAccess,
			LockMode lockMode,
			DomainResult<?> collectionKeyResult,
			DomainResult<?> collectionValueKeyResult,
			boolean isResultInitializer,
			AssemblerCreationState creationState) {
		return new ArrayInitializer(
				navigablePath,
				arrayDescriptor,
				parentAccess,
				lockMode,
				collectionKeyResult,
				collectionValueKeyResult,
				listIndexFetch,
				elementFetch,
				isResultInitializer,
				creationState
		);
	}
}
